""" hpp2plantuml module

.. _sec-module:

REVIEW Module source code
-------------------------

The package relies on a layer of objects used as intermediate between the parsed
header files (parsed using ``CppHeaderParser``) and the text output for use with
PlantUML.

The main entry point () takes as input a list of header
files and creates a object from it, which contains the internal object
representation extracted jointly from the input files.

Objects for different types (e.g. class, struct, etc.) are initialized at
instantiation time from the parsed header via the ``parse_members`` method.
Conversion to text input in PlantUML syntax is performed by the ``render`` method.

Relationships between objects are extracted from a ``Diagram`` object by listing
inheritance properties and parsing member types into
.


Usage:

.. _sec-module-usage:

REVIEW Usage
------------

The ``hpp2plantuml`` package can be used from the command line or as a module in
other applications.

Command line
~~~~~~~~~~~~

The command line usage is (``hpp2plantuml --help``):


::

    usage: hpp2plantuml [-h] [-o FILE] -i HEADER-FILE

    hpp2plantuml tool.

    optional arguments:
      -h, --help            show this help message and exit
      -o FILE, --output-file FILE
                            Output file
      -i HEADER-FILE, --input-file HEADER-FILE
                            Input file (must be quoted when using wildcards)


Input files are added using the ``-i`` option.  Inputs can be file paths or
include wildcards.  The output file is selected with the ``-o`` option.  The
output is a text file following the PlantUML syntax.

For instance, the following command will generate the input file for PlantUML
from several header files and store the output to the ``output.puml`` file.

.. code-block:: sh
    :name: usage-sh

    hpp2plantuml -i File_1.hpp -i "include/Helper_*.hpp" -o output.puml

Note that the double quotes are required when using wildcards.

Module
~~~~~~

To use as a module, simply ``import hpp2plantuml``.  The ``CreatePlantUMLFile`` can
then be used to create a PlantUML file from a set of input files.
Alternatively, the ``Diagram`` object can be used directly to build internal
objects (from files or strings).  The ``Diagram.render()`` method can be used to
produce a string output instead of writing to a text file.

"""

__title__ = "hpp2plantuml"
__description__ = "Convert C++ header files to PlantUML"
__version__ = '0.1'
__uri__ = "https://hpp2plantuml.readthedocs.io/"
__doc__ = __description__ + " <" + __uri__ + ">"
__author__ = "Thibault Marin"
__email__ = "thibault.marin@gmx.com"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2016 Thibault Marin"

from .hpp2plantuml import CreatePlantUMLFile, Diagram

__all__ = ['CreatePlantUMLFile', 'Diagram']
